@@ -5,6 +5,7 @@
 """
 import sys
 import argparse
+from pathlib import Path
 from palp.tool.create_spider import CreateSpider
 from palp.tool.create_project import CreateProject
 
@@ -39,8 +40,10 @@ def generator():
 
 
 def helper():
-    with open('../VERSION', 'r', encoding='utf-8') as f:
+    version_path = Path(__file__).parent.parent.joinpath('VERSION')
+    with open(version_path, 'r', encoding='utf-8') as f:
         version = f.read()
+        
     print(f"palp {version} 操作命令如下")
     print("\tpalp create [options] [args]")
     print("\n可选 options:")
